@@ -3,34 +3,34 @@
 #' This function takes a specially formatted R script and converts it to a
 #' literate programming document. By default normal text (documentation) should
 #' be written after the roxygen comment (\code{#'}) and code chunk options are
-#' written after \code{#+} or \code{#-} or \code{# ----}.
+#' written after \code{#+} or \code{#-} or \code{# ----} or any of these
+#' combinations replacing \code{#} with \code{--}.
 #'
 #' Obviously the goat's hair is the original R script, and the wool is the
 #' literate programming document (ready to be knitted).
-#' @param hair the path to the R script
-#' @param knit logical: whether to compile the document after conversion
-#' @param report logical: whether to generate report for \file{Rmd}, \file{Rnw}
-#'   and \file{Rtex} output (ignored if \code{knit = FALSE})
-#' @param text a character vector as an alternative way to \code{hair} to
-#'   provide the R source; if \code{text} is not \code{NULL}, \code{hair} will
-#'   be ignored
-#' @param envir the environment for \code{\link{knit}()} to evaluate the code
-#' @param format character: the output format (it takes five possible values);
-#'   the default is R Markdown
-#' @param doc a regular expression to identify the documentation lines; by
+#' @param hair Path to the R script.
+#' @param knit Logical; whether to compile the document after conversion.
+#' @param report Logical; whether to generate a report for \file{Rmd}, \file{Rnw}
+#'   and \file{Rtex} output. Ignored if \code{knit = FALSE}.
+#' @param text A character vector of code, as an alternative way to
+#'   provide the R source. If \code{text} is not \code{NULL}, \code{hair} will
+#'   be ignored.
+#' @param envir Environment for \code{\link{knit}()} to evaluate the code.
+#' @param format Character; the output format. The default is R Markdown.
+#' @param doc A regular expression to identify the documentation lines; by
 #'   default it follows the roxygen convention, but it can be customized, e.g.
 #'   if you want to use \code{##} to denote documentation, you can use
-#'   \code{'^##\\\\s*'}
-#' @param inline a regular expression to identify inline R expressions; by
+#'   \code{'^##\\\\s*'}.
+#' @param inline A regular expression to identify inline R expressions; by
 #'   default, code of the form \code{((code))} on its own line is treated as an
-#'   inline expression
-#' @param comment a pair of regular expressions for the start and end delimiters
+#'   inline expression.
+#' @param comment A pair of regular expressions for the start and end delimiters
 #'   of comments; the lines between a start and an end delimiter will be
-#'   ignored; by default, the delimiters are \verb{/*} in the beginning and
-#'   \verb{*/} in the end of a line (following the convention of C comments)
+#'   ignored. By default, the delimiters are \verb{/*} at the beginning of a line,
+#'    and \verb{*/} at the end, following the convention of C comments.
 #' @param precious logical: whether intermediate files (e.g., \code{.Rmd} files
-#'   when \code{format} is \code{"Rmd"}) should be preserved; default
-#'   \code{FALSE} if \code{knit == TRUE} and input is a file
+#'   when \code{format} is \code{"Rmd"}) should be preserved. The default is
+#'   \code{FALSE} if \code{knit} is \code{TRUE} and the input is a file.
 #' @author Yihui Xie, with the original idea from Richard FitzJohn (who named it
 #'   as \code{sowsear()} which meant to make a silk purse out of a sow's ear)
 #' @return If \code{text} is \code{NULL}, the path of the final output document,
@@ -48,25 +48,6 @@
 #' @export
 #' @seealso \code{\link{stitch}} (feed a template with an R script)
 #' @references \url{https://yihui.name/knitr/demo/stitch/}
-#' @examples #' write normal text like this and chunk options like below
-#'
-#' #+ label, opt=value
-#'
-#' # /*
-#' #' these lines are treated as comments in spin()
-#' 1+1
-#' # */
-#'
-#' (s = system.file('examples', 'knitr-spin.R', package = 'knitr'))
-#' spin(s)  # default markdown
-#' o = spin(s, knit = FALSE) # convert only; do not make a purse yet
-#' knit2html(o) # compile to HTML
-#'
-#' # other formats
-#' spin(s, FALSE, format='Rnw')  # you need to write documentclass after #'
-#' spin(s, FALSE, format='Rhtml')
-#' spin(s, FALSE, format='Rtex')
-#' spin(s, FALSE, format='Rrst')
 spin = function(
   hair, knit = TRUE, report = TRUE, text = NULL, envir = parent.frame(),
   format = c('Rmd', 'Rnw', 'Rhtml', 'Rtex', 'Rrst'),
@@ -100,8 +81,8 @@ spin = function(
       # R code; #+/- indicates chunk options
       block = strip_white(block) # rm white lines in beginning and end
       if (!length(block)) next
-      if (length(opt <- grep('^#+(\\+|-| ----+| @knitr)', block))) {
-        block[opt] = paste0(p[1L], gsub('^#+(\\+|-| ----+| @knitr)\\s*|-*\\s*$', '', block[opt]), p[2L])
+      if (length(opt <- grep(rc <- '^(#|--)+(\\+|-| ----+| @knitr)', block))) {
+        block[opt] = paste0(p[1L], gsub(paste0(rc, '\\s*|-*\\s*$'), '', block[opt]), p[2L])
       }
       if (!grepl(p1, block[1L])) {
         block = c(paste0(p[1L], p[2L]), block)
@@ -152,9 +133,9 @@ spin = function(
 #' to compile it. You can call this function in R code, or using the syntax of
 #' inline R expressions in \code{\link{spin}()} (e.g.
 #' \code{{{knitr::spin_child('script.R')}}}).
-#' @param input the filename of the input R script
-#' @param format to be passed to \code{format} in \code{spin()}; if not
-#'   provided, it will be guessed from the current knitting process
+#' @param input Filename of the input R script.
+#' @param format Passed to \code{format} in \code{spin()}. If not
+#'   provided, it will be guessed from the current knitting process.
 #' @return A character string of the knitted R script.
 #' @export
 spin_child = function(input, format) {
